@@ -10,7 +10,7 @@ use Exporter;
 use Scalar::Util qw( reftype );
 use XSLoader;
 
-our $VERSION = '1.12';
+our $VERSION = '1.14';
 
 XSLoader::load( __PACKAGE__, $VERSION );
 
@@ -179,7 +179,7 @@ File::LibMagic - Determine MIME types of data or files using libmagic
 
 =head1 VERSION
 
-version 1.12
+version 1.14
 
 =head1 SYNOPSIS
 
@@ -482,12 +482,16 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Mithun Ayachit Olaf Alders
+=for stopwords E. Choroba Mithun Ayachit Olaf Alders
 
 =over 4
 
 =item *
 
+E. Choroba <choroba@matfyz.cz>
+
+=item *
+
 Mithun Ayachit <mayachit@amfam.com>
 
 =item *
